        function getT(rr,cc){
       if(rr==1 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==1 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 25 <strong>control</strong><br>0,5,6,8,9,10,12,13,14,18,20,22,24,27,28,31,34,36,37,38,44,45,46,47,50';}
       if(rr==1 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>3</strong> miembros: 14 <br>1,3,11,16,19,23,26,29,30,32,41,42,43,49';}
       if(rr==1 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 12 <br>2,4,7,15,17,21,25,33,35,39,40,48';}
       if(rr==8 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==8 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 25 <strong>control</strong><br>0,5,6,8,9,10,12,13,14,18,20,22,24,27,28,31,34,36,37,38,44,45,46,47,50';}
       if(rr==8 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>3</strong> miembros: 14 <br>1,3,11,16,19,23,26,29,30,32,41,42,43,49';}
       if(rr==8 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 12 <br>2,4,7,15,17,21,25,33,35,39,40,48';}
       if(rr==18 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==18 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 25 <strong>control</strong><br>0,5,6,8,9,10,12,13,14,18,20,22,24,27,28,31,34,36,37,38,44,45,46,47,50';}
       if(rr==18 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>3</strong> miembros: 14 <br>1,3,11,16,19,23,26,29,30,32,41,42,43,49';}
       if(rr==18 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 12 <br>2,4,7,15,17,21,25,33,35,39,40,48';}
       if(rr==24 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==24 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 25 <strong>control</strong><br>0,5,6,8,9,10,12,13,14,18,20,22,24,27,28,31,34,36,37,38,44,45,46,47,50';}
       if(rr==24 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>3</strong> miembros: 14 <br>1,3,11,16,19,23,26,29,30,32,41,42,43,49';}
       if(rr==24 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 12 <br>2,4,7,15,17,21,25,33,35,39,40,48';}
       if(rr==44 && cc==0){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==44 && cc==1){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 25 <strong>control</strong><br>0,5,6,8,9,10,12,13,14,18,20,22,24,27,28,31,34,36,37,38,44,45,46,47,50';}
       if(rr==44 && cc==2){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>3</strong> miembros: 14 <br>1,3,11,16,19,23,26,29,30,32,41,42,43,49';}
       if(rr==44 && cc==3){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 12 <br>2,4,7,15,17,21,25,33,35,39,40,48';}
       if(rr==45 && cc==0){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==45 && cc==1){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 25 <strong>control</strong><br>0,5,6,8,9,10,12,13,14,18,20,22,24,27,28,31,34,36,37,38,44,45,46,47,50';}
       if(rr==45 && cc==2){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>3</strong> miembros: 14 <br>1,3,11,16,19,23,26,29,30,32,41,42,43,49';}
       if(rr==45 && cc==3){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 12 <br>2,4,7,15,17,21,25,33,35,39,40,48';}
}
