        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 25 <strong>control</strong><br>0,5,6,8,9,10,12,13,14,18,20,22,24,27,28,31,34,36,37,38,44,45,46,47,50';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>3</strong> miembros: 14 <br>1,3,11,16,19,23,26,29,30,32,41,42,43,49';}
       if(rr==5 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 12 <br>2,4,7,15,17,21,25,33,35,39,40,48';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 25 <strong>control</strong><br>0,5,6,8,9,10,12,13,14,18,20,22,24,27,28,31,34,36,37,38,44,45,46,47,50';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>3</strong> miembros: 14 <br>1,3,11,16,19,23,26,29,30,32,41,42,43,49';}
       if(rr==40 && cc==3){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 12 <br>2,4,7,15,17,21,25,33,35,39,40,48';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 25 <strong>control</strong><br>0,5,6,8,9,10,12,13,14,18,20,22,24,27,28,31,34,36,37,38,44,45,46,47,50';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>3</strong> miembros: 14 <br>1,3,11,16,19,23,26,29,30,32,41,42,43,49';}
       if(rr==41 && cc==3){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 12 <br>2,4,7,15,17,21,25,33,35,39,40,48';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 25 <strong>control</strong><br>0,5,6,8,9,10,12,13,14,18,20,22,24,27,28,31,34,36,37,38,44,45,46,47,50';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>3</strong> miembros: 14 <br>1,3,11,16,19,23,26,29,30,32,41,42,43,49';}
       if(rr==42 && cc==3){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 12 <br>2,4,7,15,17,21,25,33,35,39,40,48';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>9</strong> miembros: 25 <strong>control</strong><br>0,5,6,8,9,10,12,13,14,18,20,22,24,27,28,31,34,36,37,38,44,45,46,47,50';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>3</strong> miembros: 14 <br>1,3,11,16,19,23,26,29,30,32,41,42,43,49';}
       if(rr==43 && cc==3){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260814 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 12 <br>2,4,7,15,17,21,25,33,35,39,40,48';}
}
